@@ -1,10 +1,11 @@
 package MooseX::Storage::Basic;
+{
+  $MooseX::Storage::Basic::VERSION = '0.44';
+}
 BEGIN {
   $MooseX::Storage::Basic::AUTHORITY = 'cpan:STEVAN';
 }
-{
-  $MooseX::Storage::Basic::VERSION = '0.43';
-}
+# ABSTRACT: The simplest level of serialization
 use Moose::Role;
 
 use MooseX::Storage::Engine;
@@ -66,10 +67,19 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
+=for :stopwords Chris Prather Stevan Little יובל קוג'מן (Yuval Kogman) Infinity
+Interactive, Inc.
+
 =head1 NAME
 
 MooseX::Storage::Basic - The simplest level of serialization
 
+=head1 VERSION
+
+version 0.44
+
 =head1 SYNOPSIS
 
   package Point;
@@ -136,19 +146,29 @@ All complex software has bugs lurking in it, and this module is no
 exception. If you find a bug please either email me, or add the bug
 to cpan-RT.
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Chris Prather E<lt>chris.prather@iinteractive.comE<gt>
+=over 4
 
-Stevan Little E<lt>stevan.little@iinteractive.comE<gt>
+=item *
+
+Chris Prather <chris.prather@iinteractive.com>
+
+=item *
+
+Stevan Little <stevan.little@iinteractive.com>
+
+=item *
+
+יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007-2008 by Infinity Interactive, Inc.
+This software is copyright (c) 2007 by Infinity Interactive, Inc..
 
-L<http://www.iinteractive.com>
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
