@@ -1,10 +1,11 @@
 package MooseX::Storage::Engine;
+{
+  $MooseX::Storage::Engine::VERSION = '0.44';
+}
 BEGIN {
   $MooseX::Storage::Engine::AUTHORITY = 'cpan:STEVAN';
 }
-{
-  $MooseX::Storage::Engine::VERSION = '0.43';
-}
+# ABSTRACT: The meta-engine to handle collapsing and expanding objects
 use Moose;
 use Scalar::Util qw(refaddr);
 
@@ -370,10 +371,21 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
+=for :stopwords Chris Prather Stevan Little יובל קוג'מן (Yuval Kogman) Infinity
+Interactive, Inc. Plunien Jonathan Rockway Yu Jos Boumans Karen Etheridge
+Ricardo SIGNES Signes Robert Boone Shawn M Moore Tomas Doran (t0m) Yuval
+Cory Kogman t0m Watson Dagfinn Ilmari Mannsåker Florian Ragwitz Johannes
+
 =head1 NAME
 
 MooseX::Storage::Engine - The meta-engine to handle collapsing and expanding objects
 
+=head1 VERSION
+
+version 0.44
+
 =head1 DESCRIPTION
 
 There really aren't any major user serviceable parts here. However the typical
@@ -462,22 +474,29 @@ All complex software has bugs lurking in it, and this module is no
 exception. If you find a bug please either email me, or add the bug
 to cpan-RT.
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Chris Prather E<lt>chris.prather@iinteractive.comE<gt>
+=over 4
 
-Stevan Little E<lt>stevan.little@iinteractive.comE<gt>
+=item *
+
+Chris Prather <chris.prather@iinteractive.com>
+
+=item *
+
+Stevan Little <stevan.little@iinteractive.com>
+
+=item *
+
+יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007-2008 by Infinity Interactive, Inc.
+This software is copyright (c) 2007 by Infinity Interactive, Inc..
 
-L<http://www.iinteractive.com>
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-
